VoiceButtonConfig class
Configuration for button appearance and behavior
Constructors
Properties
-
Color for play/pause/error button backgrounds
final
-
Color for button icons
final
-
Size of the play/pause/error buttons
final
- errorIcon → Widget?
-
Custom widget for the error icon
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pauseIcon → Widget?
-
Custom widget for the pause icon
final
- playIcon → Widget?
-
Custom widget for the play icon
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simpleIconSize → double
-
Size of the simple play icon (only used when useSimplePlayIcon is true)
final
- useSimplePlayIcon → bool
-
Whether to show the play icon without circular background
final
Methods
-
copyWith(
{Widget? playIcon, Widget? pauseIcon, Widget? errorIcon, Color? buttonColor, Color? buttonIconColor, double? buttonSize, bool? useSimplePlayIcon, double? simpleIconSize}) → VoiceButtonConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited